==> plantuml-1.2025.4.tar.gz: plantuml-1.2025.4/src/main/java/net/sourceforge/plantuml/preproc/OptionKey.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2024, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.preproc;

public enum OptionKey {

	LANGUAGE, USE_DESCRIPTIVE_NAMES, HANDWRITTEN, DEBUG;

	public static String simplify(String s) {
		final StringBuilder result = new StringBuilder();

		for (char c : s.toCharArray())
			if ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z'))
				result.append(Character.toLowerCase(c));

		return result.toString();
	}

	public static OptionKey lazyFrom(String s) {
		for (OptionKey key : values())
			if (simplify(s).equals(simplify(key.name())))
				return key;
		return null;
	}

}

==> plantuml-1.2025.10.tar.gz: plantuml-1.2025.10/src/main/java/net/sourceforge/plantuml/preproc/OptionKey.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2024, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.preproc;

public enum OptionKey {

	LANGUAGE, USE_DESCRIPTIVE_NAMES, HANDWRITTEN, DEBUG, SVG_DESC, SVG_TITLE;

	public static String simplify(String s) {
		final StringBuilder result = new StringBuilder();

		for (char c : s.toCharArray())
			if ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z'))
				result.append(Character.toLowerCase(c));

		return result.toString();
	}

	public static OptionKey lazyFrom(String s) {
		for (OptionKey key : values())
			if (simplify(s).equals(simplify(key.name())))
				return key;
		return null;
	}

}
